@@ -1,8 +1,9 @@
-from os import remove
+import os
 from re import compile
 
 from django.conf import settings
 from django.contrib.sites.models import Site
+from django.template.context import RequestContext
 from django.template.response import HttpResponse
 from django.views.generic import TemplateView
 
@@ -10,9 +11,12 @@ from wkhtmltopdf.utils import template_to_temp_file, wkhtmltopdf
 
 
 class PDFResponse(HttpResponse):
-    def __init__(self, content, filename):
-        super(PDFResponse, self).__init__(content, 'application/pdf')
-        self.__setitem__('Content-Disposition', 'attachment; filename=%s' % filename)
+    def __init__(self, content, *args, **kwargs):
+        filename = kwargs.pop('filename', None)
+        super(PDFResponse, self).__init__(content, 'application/pdf', *args, **kwargs)
+        if filename:
+            header_content = 'attachment; filename={0}'.format(filename)
+            self.__setitem__('Content-Disposition', header_content)
 
 
 class PdfResponse(PDFResponse):
@@ -32,16 +36,27 @@ class PDFTemplateView(TemplateView):
     margin_right = 0
     margin_top = 0
     response = PDFResponse
+    _tmp_files = None
+
+    def __init__(self, *args, **kwargs):
+        self._tmp_files = []
+        super(PDFTemplateView, self).__init__(*args, **kwargs)
 
     def get(self, request, context_instance=None, *args, **kwargs):
         if request.GET.get('as', '') == 'html':
             return super(PDFTemplateView, self).get(request, *args, **kwargs)
 
-        self.context_instance = context_instance
+        if context_instance:
+            self.context_instance = context_instance
+        else:
+            self.context_instance = RequestContext(request, self.get_context_data(**kwargs))
 
-        page_path = template_to_temp_file(self.template_name, self.get_context_data(), self.context_instance)
+        page_path = template_to_temp_file(self.get_template_names(), self.get_context_data(), self.context_instance)
         pdf_kwargs = self.get_pdf_kwargs()
-        return self.response(wkhtmltopdf(page_path, **pdf_kwargs), self.get_filename())
+        output = wkhtmltopdf(page_path, **pdf_kwargs)
+        if self._tmp_files:
+            map(os.remove, self._tmp_files)
+        return self.response(output, filename=self.get_filename())
 
     def get_filename(self):
         return self.filename
@@ -54,14 +69,12 @@ class PDFTemplateView(TemplateView):
             'margin_top': self.margin_top,
             'orientation': self.orientation,
         }
-        tmp_files = []
         if self.header_template:
             kwargs['header_html'] = template_to_temp_file(self.header_template, self.get_context_data(), self.context_instance)
-            tmp_files.append(kwargs['header_html'])
+            self._tmp_files.append(kwargs['header_html'])
         if self.footer_template:
             kwargs['footer_html'] = template_to_temp_file(self.footer_template, self.get_context_data(), self.context_instance)
-            tmp_files.append(kwargs['footer_html'])
-        map(remove, tmp_files)
+            self._tmp_files.append(kwargs['footer_html'])
         return kwargs
 
     def get_context_data(self, **kwargs):
@@ -80,4 +93,4 @@ class PdfTemplateView(PDFTemplateView): #TODO: Remove this in v1.0
     def as_view(cls, **initkwargs):
         warning = '''PdfTemplateView is deprecated in favour of PDFTemplateView. It will be removed in version 1.'''
         raise PendingDeprecationWarning(warning)
-        return super(PdfTemplateView, cls).as_view(**initkwargs)
\ No newline at end of file
+        return super(PdfTemplateView, cls).as_view(**initkwargs)
